Module: Modulorails

Defined in:
lib/modulorails.rb,
lib/modulorails/data.rb,
lib/modulorails/railtie.rb,
lib/modulorails/version.rb,
lib/modulorails/configuration.rb,
lib/modulorails/validators/database_configuration.rb

Overview

Author: Matthieu ‘ciappa_m’ Ciappara The entry point of the gem. It exposes the configurator, the gathered data and the method to send those data to the intranet.

Defined Under Namespace

Modules: ApplicationHelper, Validators Classes: BaseError, BaseService, BundlerauditGenerator, Configuration, Data, DockerGenerator, Error, ErrorData, GitlabciGenerator, HealthCheckGenerator, InvalidFormatError, InvalidValueError, LogsForMethodService, Railtie, RubocopGenerator, SelfUpdateGenerator, ServiceGenerator, SidekiqGenerator, SuccessData

Constant Summary collapse

VERSION =
'1.3.0'.freeze
COMPARABLE_RUBY_VERSION =

Useful to compare the current Ruby version

Gem::Version.new(RUBY_VERSION)

Class Attribute Summary collapse

Class Method Summary collapse

Class Attribute Details

.configurationModulorails::Configuration

A configuration getter.

Returns:

Author:

  • Matthieu ‘ciappa_m’ Ciappara



56
57
58
# File 'lib/modulorails.rb', line 56

def configuration
  @configuration ||= Modulorails::Configuration.new
end

Class Method Details

.check_database_configObject

Check the database configuration respects Modulotech’s norms

Author:

  • Matthieu ‘ciappa_m’ Ciappara



126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/modulorails.rb', line 126

def check_database_config
  invalid_rules = Modulorails::Validators::DatabaseConfiguration.call
  return true if invalid_rules.empty?

  puts('[Modulorails] The database configuration (config/database.yml) has warnings:')
  invalid_rules.each do |rule|
    t_rule = I18n.t(rule, scope: :modulorails, locale: :en)
    puts("[Modulorails]    Invalid database configuration: #{t_rule}")
  end

  false
end

.configure {|configuration| ... } ⇒ Modulorails::Configuration

When a block is given, it allows to define or update the current configuration. Without a block, this methods is just a configuration getter.

Yields:

  • (configuration)

    Block with the current configuration; optional

Yield Parameters:

Returns:

Author:

  • Matthieu ‘ciappa_m’ Ciappara



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/modulorails.rb', line 39

def configure
  # Get the current configuration if no block is given
  return configuration unless block_given?

  # Pass the configuration to the block and let the block do what it wants (probably update the
  # configuration)
  yield configuration

  # Return the (probably updated) current configuration
  configuration
end

.dataModulorails::Data

A data getter.

Returns:

Author:

  • Matthieu ‘ciappa_m’ Ciappara



65
66
67
# File 'lib/modulorails.rb', line 65

def data
  @data ||= Modulorails::Data.new
end

.generate_bundleraudit_templateObject

Generate a bundler-audit configuration.

Author:

  • Matthieu ‘ciappa_m’ Ciappara



172
173
174
# File 'lib/modulorails.rb', line 172

def generate_bundleraudit_template
  Modulorails::BundlerauditGenerator.new([], {}, {}).invoke_all
end

.generate_ci_templateObject

Generate a CI/CD template unless it was already done. The check is done using a ‘keepfile’.

Author:

  • Matthieu ‘ciappa_m’ Ciappara



117
118
119
120
121
# File 'lib/modulorails.rb', line 117

def generate_ci_template
  return if File.exist?(Rails.root.join('.modulorails-gitlab-ci'))

  Modulorails::GitlabciGenerator.new([], {}, {}).invoke_all
end

.generate_healthcheck_templateObject

Generate a health_check configuration unless it was already done. The check is done using a ‘keepfile’.

Author:

  • Matthieu ‘ciappa_m’ Ciappara



156
157
158
159
160
# File 'lib/modulorails.rb', line 156

def generate_healthcheck_template
  return if File.exist?(Rails.root.join('.modulorails-health_check'))

  Modulorails::HealthCheckGenerator.new([], {}, {}).invoke_all
end

.generate_rubocop_templateObject

Generate a rubocop configuration.

Author:

  • Matthieu ‘ciappa_m’ Ciappara



165
166
167
# File 'lib/modulorails.rb', line 165

def generate_rubocop_template
  Modulorails::RubocopGenerator.new([], {}, {}).invoke_all
end

.self_updateObject

Check the last version of Modulorails available on rubygems and update if there was a publication

Author:

  • Matthieu ‘ciappa_m’ Ciappara



143
144
145
146
147
148
149
150
# File 'lib/modulorails.rb', line 143

def self_update
  unless configuration.no_auto_update
    Modulorails::SelfUpdateGenerator.new([], {},
                                         {}).invoke_all
  end
rescue StandardError => e
  puts("[Modulorails] An error occured: #{e.class} - #{e.message}")
end

.send_dataHTTParty::Response

Send the ‘#data` to the Intranet as JSON. HTTParty is used to send the POST request.

Returns:

  • (HTTParty::Response)

    The response of the intranet

Raises:

  • (Modulorails::Error)

    If the endpoint or the API key of the intranet were not configured

Author:

  • Matthieu ‘ciappa_m’ Ciappara



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/modulorails.rb', line 75

def send_data
  # If no endpoint and/or no API key is configured, it is impossible to send the data to the
  # intranet and thus we raise an error: it is the only error we want to raise since it goes
  # against one of the main goals of the gem and the gem's user is responsible.
  unless configuration.endpoint && configuration.api_key
    raise Error.new('No endpoint or api key')
  end

  # Define the headers of the request ; sending JSON and API key to authenticate the gem on
  # the intranet
  headers = {
    'Content-Type' => 'application/json', 'X-MODULORAILS-TOKEN' => configuration.api_key
  }

  # Define the JSON body of the request
  body = data.to_params.to_json

  # Prevent HTTParty to raise error and crash the server in dev
  begin
    # Post to the configured endpoint on the Intranet
    response = HTTParty.post(configuration.endpoint, headers: headers, body: body)

    # According to the API specification, on a "Bad request" response, the server explicits what
    # went wrong with an `errors` field. We do not want to raise since the gem's user is not
    # (necessarily) responsible for the error but we still need to display it somewhere to warn
    # the user something went wrong.
    puts("[Modulorails] Error: #{response['errors'].join(', ')}") if response.code == 400

    # Return the response to allow users to do some more
    response
  rescue StandardError => e
    # Still need to notify the user
    puts("[Modulorails] Error: Could not post to #{configuration.endpoint}")
    puts e.message
    nil
  end
end